DoClientRequest

Struct DoClientRequest 

pub struct DoClientRequest<'a> { /* private fields */ }
A publisheable request ready to be published to the given client

Implementations

Source

impl DoClientRequest<'_>

pub fn try_request(self) -> Result<ResponseFut, TryCommandError>

Publish this request if there’s enough immediately available space in the internal buffers

This method will publish the given request only if there’s enough immediately available space to enqueue it in the client’s networking stack.

Errors

It returns an error if the client’s buffer is full or if the client has been closed.